@@ -38,12 +38,15 @@ const QString KDateCacheFile = "/opt/fapman-cache/dates.cache";
 const QString KAptSourceList = "/opt/fapman-cache/sources.list";
 const QString KAptListDir = "/opt/fapman-cache/lists";
 const QString KAptArchivePartialDir = "/var/cache/apt/archives/partial";
+const QString KAptPreferencesFile = "/etc/apt/preferences";
 
 const QString KDpkgStatusFile = "/var/lib/dpkg/status";
 const QString KDpkgInfoDir = "/var/lib/dpkg/info";
 
 const int KListExpireTime = 3600;
 
+const int KDataReadBufferSize = 100000;
+
 class MainWindow;
 class FileReadThread;
 class DateFetchThread;
@@ -127,6 +130,7 @@ private:
 	void readBlacklist();
 	void writeDateCache();
 	void readDateCache();
+	void readPinnedPackages();
 
 private slots:
 	void errorAptGetUpdate(QProcess::ProcessError error);
@@ -199,6 +203,7 @@ private:
 	QStringList iBlacklist;
 
 	multiLine iMultiLine;
+	char* iDataReadBuffer;
 
 	int iDateRequestsWaiting;
 	int iDateRequestsSent;
