@@ -36,6 +36,7 @@ dimmer::dimmer(QWidget *parent) :
 	iAnimY = this->rect().height()-this->rect().height()/4;
 	iProgress = -1;
 	iUpdateAnim = false;
+	iDownloadSpeed = -1;
 
 	iTimer = new QTimer(this);
 	connect(iTimer,SIGNAL(timeout()),this,SLOT(timerEvent()));
@@ -83,6 +84,13 @@ void dimmer::paintEvent(QPaintEvent *)
 		painter.setPen( QApplication::palette().color(QPalette::Highlight) );
 		int pw = ( rect().right()-rect().left()-60 ) * iProgress / 100;
 		painter.drawRect(rect().left()+30, rect().bottom()-30, pw, 10 );
+
+		if( iDownloadSpeed >= 0 ) {
+			painter.setBrush( QApplication::palette().color(QPalette::BrightText) );
+			painter.setPen( QApplication::palette().color(QPalette::BrightText) );
+			QRect textrect(rect().left(),rect().bottom()-70,rect().width(),30);
+			painter.drawText(textrect,QString("%1 kB/s").arg(iDownloadSpeed),Qt::AlignHCenter|Qt::AlignVCenter);
+		}
 	}
 }
 
@@ -113,6 +121,7 @@ void dimmer::dim(QString title, QString message)
 	iBusy = true;
 	iLabel->setText("<font color=\"" + colorname + "\"><b><u>" + iTitle + "</u></b><br><br>" + message + "</font>");
 	iProgress = -1;
+	iDownloadSpeed = -1;
 	iAnim = 0;
 	iAnimDir = 1;
 
@@ -129,9 +138,17 @@ void dimmer::updateText(QString message)
 void dimmer::setProgress(int p_)
 {
 	iProgress = p_;
+	if( p_==-1 )
+		iDownloadSpeed = -1;
 	repaint(0,rect().bottom()-30,rect().width(),20);
 }
 
+void dimmer::setDownloadSpeed(int kbps_)
+{
+	iDownloadSpeed = kbps_;
+	repaint(QRect(rect().left(),rect().bottom()-70,rect().width(),30));
+}
+
 void dimmer::undim()
 {
 	iBusy = false;
