@@ -57,8 +57,10 @@ public:
 	bool confirmDialog(QString title, QString msg);
 	void setNextOperation(nextOperation op_) { iNextOperation=op_; }
 
-public slots:
 	void on_btnUpdate_clicked();
+
+public slots:
+	void orientationChanged();
 #ifdef Q_WS_MAEMO_5
 	Q_SCRIPTABLE int top_application();
 #endif
@@ -68,6 +70,7 @@ protected:
 
 private:
 	void dateFetchAsk();
+	void showFreeSpace();
 
     Ui::MainWindow *ui;
 	AAptInterface* iAptInterface;
@@ -83,16 +86,18 @@ private:
 	nextOperation iNextOperation;
 	Phonon::MediaObject* iMediaObject;
 
-private slots:
-	void on_actionLoad_file_triggered();
-	void on_actionOptions_triggered();
-	void on_actionView_log_triggered();
 	void on_btnRepos_clicked();
-	void on_actionClean_triggered();
-	void on_actionAbout_triggered();
 	void on_btnUpgrade_clicked();
 	void on_btnListInstallable_clicked();
 	void on_btnListInstalled_clicked();
+
+private slots:
+	void on_listWidget_itemClicked(QListWidgetItem* item);
+ void on_actionLoad_file_triggered();
+	void on_actionOptions_triggered();
+	void on_actionView_log_triggered();
+	void on_actionClean_triggered();
+	void on_actionAbout_triggered();
 };
 
 #endif // MAINWINDOW_H
