@@ -255,3 +255,11 @@ bool Package::versionConflicts(QString conflictVer, QString operVer)
 
 	return confl;
 }
+
+QString Package::maintainerRichText()
+{
+	QString m = iMaintainer;
+	m.replace('<',"&lt;");
+	m.replace('>',"&gt;");
+	return m;
+}
