@@ -62,6 +62,7 @@ public:
 	inline void appendSuggests(QByteArray line_) { iSuggests << line_.split(','); }
 	inline void appendUpgradeDescription(QByteArray d_) { iUpgradeDescription.append(d_); }
 	inline void setPinned(bool p_) { iPinned=p_; }
+	inline void setMaintainer(QByteArray m_) { iMaintainer = m_; }
 
 	void convertIcon();
 
@@ -99,6 +100,7 @@ public:
 	inline QList<QByteArray> recommends() { return iRecommends; }
 	inline QList<QByteArray> suggests() { return iSuggests; }
 	inline bool isPinned() { return iPinned; }
+	QString maintainerRichText();
 
 	QStringList checkConflicts_RichText();
 
@@ -128,6 +130,7 @@ private:
 	QList<Repository*> iRepositories;
 	BlacklistSelect::blackList iBlacklist;
 	QByteArray iUpgradeDescription;
+	QByteArray iMaintainer;
 
 	QByteArray iIconData;
 	QPixmap* iIcon;
