@@ -385,6 +385,10 @@ void PackageSelector::on_radioTabBasic_clicked()
 		}
 	}
 
+	if( !iPkg->maintainerRichText().isEmpty() ) {
+		longtext +="Maintainer: " + iPkg->maintainerRichText() + "<br>";
+	}
+
 	longtext += "<br>" + iPkg->descShort();
 	QString descLong = iPkg->descLong();
 	if( descLong.length()>0 ) {
