@@ -29,13 +29,14 @@ namespace Ui {
 }
 
 class AAptInterface;
+class Settings;
 
 class PackageSelector : public QDialog
 {
     Q_OBJECT
 
 public:
-	explicit PackageSelector(Package* pkg, AAptInterface* apt, QWidget *parent);
+	explicit PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, QWidget *parent);
     ~PackageSelector();
 
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
@@ -63,8 +64,10 @@ private:
     Ui::PackageSelector *ui;
 	Package* iPkg;
 	AAptInterface* iAptInterface;
+	Settings* iSettings;
 	QNetworkAccessManager* iNetworkAccessManager;
 	bool iChangelogFetched;
+	bool iFetchInProgress;
 	QString iChangelog;
 
 private slots:
