@@ -21,14 +21,16 @@
 #include "repoview.h"
 #include "ui_repoview.h"
 #include "mainwindow.h"
-#include "aptinterface.h"
+#include "aaptinterface.h"
 #include "confirmdialog.h"
+#include "repository.h"
+#include "repoedit.h"
 
 RepoView::RepoView(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::RepoView)
 {
-	iMainWindow = static_cast<MainWindow*>(parent);
+	iMainWindow = dynamic_cast<MainWindow*>(parent);
 	ui->setupUi(this);
 #ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -58,28 +60,22 @@ void RepoView::changeEvent(QEvent *e)
 
 void RepoView::openWin()
 {
-	iModified = false;
-	QStringList repos = iAptInterface->getRepositories();
+	if( !isVisible() ) {
+		iModified = false;
+	}
 
 	ui->listWidget->clear();
 
-	for( int i=0; i<repos.count(); i++ )
+	for( int i=0; i<iAptInterface->repositories()->count(); i++ )
 	{
-		QString add = repos.at(i);
-		if( add.startsWith("#") )
-		{
-			ui->listWidget->addItem( add.mid(1) );
-		} else {
-			ui->listWidget->addItem( add );
-			ui->listWidget->item(i)->setSelected(true);
-		}
-		QSize s = ui->listWidget->item(i)->sizeHint();
-		s.setHeight(60);
-		s.setWidth(750);
-		ui->listWidget->item(i)->setSizeHint( s );
-		QFont f = ui->listWidget->item(i)->font();
-		f.setPointSize( f.pointSize()-1 );
-		ui->listWidget->item(i)->setFont(f);
+		QListWidgetItem* l = new QListWidgetItem( ui->listWidget );
+		if( iAptInterface->repositories()->at(i)->enabled() )
+			l->setIcon(QPixmap(":/icons/icons/pkg_install.png"));
+		else
+			l->setIcon(QPixmap(":/icons/icons/pkg_remove.png"));
+		l->setText( iAptInterface->repositories()->at(i)->name() );
+		l->setData(Qt::UserRole, i);
+		ui->listWidget->addItem( l );
 	}
 
 	show();
@@ -90,26 +86,42 @@ void RepoView::closeEvent(QCloseEvent *event)
 	event->accept();
 
 	if( iModified )
-		iMainWindow->on_btnUpdate_clicked();
-}
-
-void RepoView::on_btnSave_clicked()
-{
-	QStringList repos;
-	for( int i=0; i<ui->listWidget->count(); i++ )
 	{
-		if( ui->listWidget->item(i)->isSelected() )
-			repos.append( ui->listWidget->item(i)->text() );
-		else
-			repos.append( "#" + ui->listWidget->item(i)->text() );
+		iAptInterface->writeRepositories();
+		iMainWindow->on_btnUpdate_clicked();
+	}
+}
+
+void RepoView::on_btnNew_clicked()
+{
+	Repository* n = new Repository();
+	iAptInterface->repositories()->append(n);
+
+	// add an option to set these directly
+	//"deb http://repository.maemo.org/extras-testing/ fremantle free non-free"
+	//"deb http://repository.maemo.org/extras-devel/ fremantle free non-free";
+
+	RepoEdit e(iAptInterface, n, iAptInterface->repositories()->count()-1, this);
+	if( !e.exec() ) {
+		if( n ) {
+			delete n;
+			iAptInterface->repositories()->removeAt( iAptInterface->repositories()->count()-1 );
+			n=0;
+		}
+	} else {
+		iModified = true;
 	}
 
-	if( iAptInterface->writeRepositories( repos ) ) {
-		iModified = true;
-	} else {
-		ConfirmDialog c(false, this);
-		c.setText("Error","Unable to write repository list");
-		c.exec();
+	openWin();
+}
+
+void RepoView::on_listWidget_itemClicked(QListWidgetItem* item)
+{
+	Repository* r = iAptInterface->repositories()->at( item->data(Qt::UserRole).toInt() );
+	if( r!=0 ) {
+		RepoEdit e(iAptInterface, r, item->data(Qt::UserRole).toInt(), this);
+		if( e.exec() )
+			iModified = true;
+		openWin();
 	}
-	this->close();
 }
