@@ -28,6 +28,7 @@ RotatingBackground::RotatingBackground(QWidget *parent) :
 
 void RotatingBackground::loadWallpaper()
 {
+	/*
 	QString loadfile = "/home/user/.backgrounds/background-1.png";
 	QFileInfo custombg("/root/.fapman/wallpaper.png");
 	bool custom = false;
@@ -35,6 +36,8 @@ void RotatingBackground::loadWallpaper()
 		loadfile = "/root/.fapman/wallpaper.png";
 		custom = true;
 	}
+	*/
+	QString loadfile = "/root/.fapman/wallpaper.png";
 
 	iWallpaperLandscape.load(loadfile);
 	if( !iWallpaperLandscape.isNull() ) {
@@ -43,6 +46,7 @@ void RotatingBackground::loadWallpaper()
 		iWallpaperPortrait = iWallpaperLandscape.transformed(t);
 	}
 
+	/*
 	if( !custom && !iWallpaperLandscape.isNull() && !iWallpaperPortrait.isNull() )
 	{
 		QPainter l( &iWallpaperLandscape );
@@ -58,6 +62,7 @@ void RotatingBackground::loadWallpaper()
 		l.drawRect( 0, 0, iWallpaperLandscape.rect().width(), iWallpaperLandscape.rect().height() );
 		p.drawRect( 0, 0, iWallpaperPortrait.rect().width(), iWallpaperPortrait.rect().height() );
 	}
+	*/
 }
 
 void RotatingBackground::paintEvent(QPaintEvent *)
